==> polars-core-0.19.0.crate: polars-core-0.19.0/src/prelude.rs <==
//! Everything you need to get started with Polars.
pub(crate) use crate::chunked_array::to_array;
pub(crate) use crate::frame::groupby::aggregations::*;
pub(crate) use crate::utils::CustomIterTools;
pub use crate::{
    chunked_array::{
        arithmetic::Pow,
        builder::{
            BooleanChunkedBuilder, ChunkedBuilder, ListBooleanChunkedBuilder, ListBuilderTrait,
            ListPrimitiveChunkedBuilder, ListUtf8ChunkedBuilder, NewChunkedArray,
            PrimitiveChunkedBuilder, Utf8ChunkedBuilder,
        },
        iterator::{IntoNoNullIterator, PolarsIterator},
        ops::{aggregate::*, *},
        ChunkedArray,
    },
    datatypes,
    datatypes::*,
    df,
    error::{PolarsError, Result},
    frame::{groupby::GroupTuples, hash_join::JoinType, DataFrame},
    named_from::NamedFrom,
    series::{
        arithmetic::{LhsNumOps, NumOpsDispatch},
        IntoSeries, Series, SeriesTrait,
    },
    testing::*,
    utils::IntoVec,
    vector_hasher::VecHash,
};
pub(crate) use arrow::array::*;
pub use arrow::datatypes::{Field as ArrowField, Schema as ArrowSchema};
pub use polars_arrow::prelude::{LargeListArray, LargeStringArray, QuantileInterpolOptions};
pub(crate) use polars_arrow::trusted_len::TrustedLen;
pub use std::sync::Arc;

#[cfg(feature = "object")]
pub use crate::chunked_array::object::PolarsObject;
#[cfg(feature = "temporal")]
pub use crate::chunked_array::temporal::conversion::*;
#[cfg(feature = "checked_arithmetic")]
pub use crate::series::arithmetic::checked::NumOpsDispatchChecked;

#[cfg(feature = "rank")]
pub use crate::chunked_array::ops::unique::rank::{RankMethod, RankOptions};

#[cfg(feature = "rolling_window")]
pub use crate::chunked_array::ops::rolling_window::RollingOptions;

#[cfg(feature = "dynamic_groupby")]
pub use polars_time::{groupby::ClosedWindow, Duration};

#[cfg(feature = "ewma")]
pub use polars_arrow::kernels::ewm::EWMOptions;

pub(crate) use polars_arrow::export::*;

==> polars-core-0.19.1.crate: polars-core-0.19.1/src/prelude.rs <==
//! Everything you need to get started with Polars.
pub(crate) use crate::chunked_array::to_array;
pub(crate) use crate::frame::groupby::aggregations::*;
pub(crate) use crate::utils::CustomIterTools;
pub use crate::{
    chunked_array::{
        arithmetic::Pow,
        builder::{
            BooleanChunkedBuilder, ChunkedBuilder, ListBooleanChunkedBuilder, ListBuilderTrait,
            ListPrimitiveChunkedBuilder, ListUtf8ChunkedBuilder, NewChunkedArray,
            PrimitiveChunkedBuilder, Utf8ChunkedBuilder,
        },
        iterator::{IntoNoNullIterator, PolarsIterator},
        ops::{aggregate::*, *},
        ChunkedArray,
    },
    datatypes,
    datatypes::*,
    df,
    error::{PolarsError, Result},
    frame::{groupby::GroupsProxy, hash_join::JoinType, DataFrame},
    named_from::NamedFrom,
    series::{
        arithmetic::{LhsNumOps, NumOpsDispatch},
        IntoSeries, Series, SeriesTrait,
    },
    testing::*,
    utils::IntoVec,
    vector_hasher::VecHash,
};
pub(crate) use arrow::array::*;
pub use arrow::datatypes::{Field as ArrowField, Schema as ArrowSchema};
pub use polars_arrow::prelude::{LargeListArray, LargeStringArray, QuantileInterpolOptions};
pub(crate) use polars_arrow::trusted_len::TrustedLen;
pub use std::sync::Arc;

#[cfg(feature = "object")]
pub use crate::chunked_array::object::PolarsObject;
#[cfg(feature = "temporal")]
pub use crate::chunked_array::temporal::conversion::*;
#[cfg(feature = "checked_arithmetic")]
pub use crate::series::arithmetic::checked::NumOpsDispatchChecked;

#[cfg(feature = "rank")]
pub use crate::chunked_array::ops::unique::rank::{RankMethod, RankOptions};

#[cfg(feature = "rolling_window")]
pub use crate::chunked_array::ops::rolling_window::RollingOptions;

#[cfg(feature = "dynamic_groupby")]
pub use polars_time::{groupby::ClosedWindow, Duration};

#[cfg(feature = "ewma")]
pub use polars_arrow::kernels::ewm::EWMOptions;

pub(crate) use polars_arrow::export::*;
